"""Top-level package for pythx."""

__author__ = """Dominik Muhs"""
__email__ = "dominik.muhs@consensys.net"
__version__ = "1.7.1"

from mythx_models.exceptions import MythXAPIError
from pythx.api.client import Client
